@@ -17,16 +17,16 @@ Classes
     :nosignatures:
 
     AssemblyArtist
-    AssemblyHelper
     BlockArtist
-    BlockHelper
 
 """
 from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
-from .artists import *  # noqa: F401 F403
+from .artists import BlockArtist
+from .artists import AssemblyArtist
 
 
-__all__ = [name for name in dir() if not name.startswith('_')]
+__all__ = [
+    'BlockArtist',
+    'AssemblyArtist'
+]
