@@ -19,10 +19,8 @@ Classes
     AssemblyPlotter
 
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from .plotter import AssemblyPlotter
 
-from .plotter import *  # noqa: F401 F403
-
-__all__ = [name for name in dir() if not name.startswith('_')]
+__all__ = [
+    'AssemblyPlotter'
+]
