@@ -20,9 +20,10 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-# from .helpers import *  # noqa: F401 F403
-from .artists import *  # noqa: F401 F403
-# from .objects import *  # noqa: F401 F403
+from .artists.blockartist import BlockArtist
+from .artists.assemblyartist import AssemblyArtist
 
-
-__all__ = [name for name in dir() if not name.startswith('_')]
+__all__ = [
+    'BlockArtist',
+    'AssemblyArtist'
+]
